import Polyglot from 'node-polyglot'
import Vue from 'vue'

import de from '@/i18n/de'
import en from '@/i18n/en'

export const translationVm = new Vue({
  data() {
    return {
      availableLocales: { de, en },
      activeLocale: 'de',
      polyglot: null,
    }
  },
  created() {
    const potentialLocale = 'de' // navigator.language.substring(0, 2)
    this.activeLocale = Object.prototype.hasOwnProperty.call(this.availableLocales, potentialLocale)
      ? potentialLocale
      : 'de'

    const phrases = this.availableLocales[this.activeLocale]
    this.polyglot = new Polyglot({ phrases })
  },

  methods: {
    getPhrasesForLocale(locale) {
      return this.availableLocales[locale]
    },

    locale(newLocale) {
      const phrases = this.getPhrasesForLocale(newLocale)

      this.activeLocale = newLocale
      this.polyglot = new Polyglot({ phrases })
      this.polyglot.locale(newLocale)
    },

    t(text, context = {}) {
      return this.polyglot.t(text, context)
    },

    te(key) {
      return this.polyglot.has(key)
    },
  },
})

export default {
  install(Vue) {
    Vue.prototype.$activeLocale = () => translationVm.activeLocale

    Vue.prototype.$locale = function (newLocale) {
      translationVm.locale(newLocale)
    }

    Vue.prototype.$t = function (text, context = {}) {
      return translationVm.t(text, context)
    }

    // IMHO this is not the best naming for this function, but it is consistent
    // with the vue-i18n library that most people working on vue applications
    // will be familiar with.
    Vue.prototype.$te = function (key) {
      return translationVm.te(key)
    }
  },
}
