import vue from '@vitejs/plugin-vue'
import path from 'path'
import { defineConfig } from 'vite'

export default defineConfig({
  base: '',
  // Traditionally we’ve used the VUE_ prefix for env variables as that was the default
  // environment variable prefix in the vue-cli/webpack based build system.
  // Migrating to the VITE_ prefix might be advisable in the future, but there
  // is no immediate need or benefit in doing so, so we support both.
  envPrefix: ['VUE_', 'VITE_'],
  server: {
    port: 8080,
    strictPort: true,
  },
  build: {
    rollupOptions: {
      input: {
        main: path.resolve(__dirname, 'index.html'),
        oidc_callback: path.resolve(__dirname, 'oidc_callback.html'),
        oidc_callback_silent_renew: path.resolve(__dirname, 'oidc_callback_silentRenew.html'),
      },
    },
  },
  resolve: {
    alias: {
      vue: '@vue/compat',
      '@': path.resolve(__dirname, 'src'),
      jquery: path.resolve(__dirname, 'node_modules', 'jquery', 'dist', 'jquery.js'),
      'lodash.defaultsdeep': path.resolve(
        __dirname,
        'node_modules',
        'lodash.defaultsdeep',
        'index.js',
      ),
      moment: path.resolve(__dirname, 'node_modules', 'moment', 'moment.js'),
    },
  },
  plugins: [
    vue({
      template: {
        compilerOptions: {
          compatConfig: {
            MODE: 2,
          },
        },
      },
    }),
  ],
})
